@@ -95,7 +95,7 @@
  *
  * - A list
  *
- * - Inside markup
+ * - that is not recognised as markdown
  *
  * </refsect3>
  *
@@ -155,7 +155,7 @@
 /**
  * SECTION:object3
  * @title: GtkdocObject3
- * @short_description: class that is mostly undocuemnted
+ * @short_description: class that is mostly undocumented
  *
  * This file contains non-sense code for the sole purpose of testing the docs.
  */
@@ -352,15 +352,14 @@ static void gtkdoc_object_class_init (GtkdocObjectClass *klass) {
 #endif
 
   /**
-   * GtkdocObject:otest:
+   * GtkdocObject:otest: (type GList(GtkdocObject2))
    *
    * Since: 0.1
    */
   g_object_class_install_property (gobject_class,GTKDOC_OBJECT_TEST,
-                                  g_param_spec_string ("otest",
+                                  g_param_spec_pointer ("otest",
                                      "otest prop",
                                      "dummy property for object",
-                                     "dummy", /* default value */
                                      G_PARAM_READWRITE));
 
   /**
