@@ -77,6 +77,40 @@ done
 if test $nok -gt 0 ; then failed=`expr $failed + 1`; fi
 tested=`expr $tested + 1`
 
+# check validity of devhelp2 files
+nok=0
+for file in $dir/*/docs*/html/*.devhelp2; do
+  xmllint --noout --nonet --schema $ABS_TOP_SRCDIR/devhelp2.xsd $file
+  if test $? != 0 ; then
+    echo 1>&2 "devhelp2 xml validity check failed for $file"
+    nok=`expr $nok + 1`;
+  fi
+done
+if test $nok -gt 0 ; then failed=`expr $failed + 1`; fi
+tested=`expr $tested + 1`
+
+
+# check stability of generated xml/html
+nok=0
+for path in $dir/*/docs*; do
+  if test -d $path/xml.ref; then
+    diff -u $path/xml.ref $path/xml
+    if test $? = 1 ; then
+      echo 1>&2 "difference in generated xml for $path"
+      nok=`expr $nok + 1`;
+    fi
+  fi
+  if test -d $path/html.ref; then
+    diff -u $path/html.ref $path/html
+    if test $? = 1 ; then
+      echo 1>&2 "difference in generated html for $path"
+      nok=`expr $nok + 1`;
+    fi
+  fi
+done
+if test $nok -gt 0 ; then failed=`expr $failed + 1`; fi
+tested=`expr $tested + 1`
+
 
 # summary
 successes=`expr $tested - $failed`
